pub struct Dfsdm<'d, T: Instance, C: ClockOutputMode> { /* private fields */ }Expand description
DFSDM driver entry point.
Implementations
Sourceimpl<'d, T> Dfsdm<'d, T, OutputEnabled>where
T: Instance,
impl<'d, T> Dfsdm<'d, T, OutputEnabled>where
T: Instance,
Sourcepub fn new_ckout(
peri: Peri<'d, T>,
ckout: Peri<'d, impl CkoutPin<T>>,
ckout_source: CkoutSource,
ckout_div: CkoutDivider,
) -> Self
pub fn new_ckout( peri: Peri<'d, T>, ckout: Peri<'d, impl CkoutPin<T>>, ckout_source: CkoutSource, ckout_div: CkoutDivider, ) -> Self
Create the driver with an output clock on ckout.
Sourceimpl<'d, T> Dfsdm<'d, T, OutputDisabled>where
T: Instance,
impl<'d, T> Dfsdm<'d, T, OutputDisabled>where
T: Instance,
Sourceimpl<'d, T, C> Dfsdm<'d, T, C>where
T: Instance + HasHwid,
C: ClockOutputMode,
impl<'d, T, C> Dfsdm<'d, T, C>where
T: Instance + HasHwid,
C: ClockOutputMode,
Sourceimpl<'d, T, C> Dfsdm<'d, T, C>where
T: Instance,
C: ClockOutputMode,
impl<'d, T, C> Dfsdm<'d, T, C>where
T: Instance,
C: ClockOutputMode,
Sourcepub fn configure_pins<F, OUT>(
self,
f: F,
) -> (DfsdmCommon<'d, T, Enabled>, <OUT as ChannelCfgTuple<'d, T, C>>::Split)
pub fn configure_pins<F, OUT>( self, f: F, ) -> (DfsdmCommon<'d, T, Enabled>, <OUT as ChannelCfgTuple<'d, T, C>>::Split)
The closure receives one selector per transceiver the instance actually has, and must return one token per transceiver, as a tuple in the same order.
// DFSDM instance with 8-transceiver capability:
ⓘ
dfsdm1.configure_pins(|tb| {
(
tb.ch0.datin_ckin(p.PC1, p.PC0),
tb.ch1.datin(p.PC3),
tb.ch2.datin_ckin(p.PC5, p.PC4),
tb.ch3.none(),
tb.ch4.none(),
tb.ch5.none(),
tb.ch6.none(),
tb.ch7.none(),
)
});// DFSDM instance with 2-transceiver capability:
ⓘ
dfsdm1.configure_pins(|tb| {
(
tb.ch0.datin_ckin(p.PC1, p.PC0),
tb.ch1.datin(p.PC3),
)
});Auto Trait Implementations
impl<'d, T, C> !UnwindSafe for Dfsdm<'d, T, C>
impl<'d, T, C> Freeze for Dfsdm<'d, T, C>
impl<'d, T, C> RefUnwindSafe for Dfsdm<'d, T, C>where
PhantomData<T>: RefUnwindSafe,
PhantomData<C>: RefUnwindSafe,
Option<Peri<'d, T>>: RefUnwindSafe,
impl<'d, T, C> Send for Dfsdm<'d, T, C>
impl<'d, T, C> Sync for Dfsdm<'d, T, C>
impl<'d, T, C> Unpin for Dfsdm<'d, T, C>
impl<'d, T, C> UnsafeUnpin for Dfsdm<'d, T, C>